@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration
 
-our $VERSION = '0.0307';
+our $VERSION = '0.0308';
 
 use Moo;
 use strictures 2;
@@ -55,7 +55,7 @@ has min_size => (
 sub _build_min_size {
     my ($self) = @_;
 
-    my @sizes = map { $self->duration($_) } @{ $self->pool };
+    my @sizes = map { $self->_duration($_) } @{ $self->pool };
 
     return min(@sizes);
 }
@@ -67,12 +67,6 @@ has verbose => (
 );
 
 
-sub duration {
-    my ( $self, $name ) = @_;
-    return $self->names->{$name};
-}
-
-
 sub motif {
     my ($self) = @_;
 
@@ -84,7 +78,7 @@ sub motif {
 
     while ( $sum < $self->size ) {
         my $name = $self->pool_code->();
-        my $size = $self->duration($name);
+        my $size = $self->_duration($name);
         my $diff = $self->size - $sum;
 
         last
@@ -105,6 +99,11 @@ sub motif {
     return $motif;
 }
 
+sub _duration {
+    my ( $self, $name ) = @_;
+    return $self->names->{$name};
+}
+
 1;
 
 __END__
@@ -119,7 +118,7 @@ Music::Duration::Partition - Partition a musical duration
 
 =head1 VERSION
 
-version 0.0307
+version 0.0308
 
 =head1 SYNOPSIS
 
@@ -209,12 +208,6 @@ Show the progress of the B<motif> method.
 
 Create a new C<Music::Duration::Partition> object.
 
-=head2 duration
-
-  $duration = $mdp->duration($duration_name);
-
-Return the value of the given duration name.
-
 =head2 motif
 
   $motif = $mdp->motif;
